Class: Google::Cloud::Firestore::Admin::V1::Backup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/firestore/admin/v1/backup.rb

Overview

A Backup of a Cloud Firestore Database.

The backup contains all documents and index configurations for the given database at a specific point in time.

Defined Under Namespace

Modules: State Classes: Stats

Instance Attribute Summary collapse

Instance Attribute Details

#database::String (readonly)

Returns Output only. Name of the Firestore database that the backup is from.

Format is projects/{project}/databases/{database}.

Returns:

  • (::String)

    Output only. Name of the Firestore database that the backup is from.

    Format is projects/{project}/databases/{database}.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/firestore/admin/v1/backup.rb', line 64

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Backup specific statistics.
  # @!attribute [r] size_bytes
  #   @return [::Integer]
  #     Output only. Summation of the size of all documents and index entries in
  #     the backup, measured in bytes.
  # @!attribute [r] document_count
  #   @return [::Integer]
  #     Output only. The total number of documents contained in the backup.
  # @!attribute [r] index_count
  #   @return [::Integer]
  #     Output only. The total number of index entries contained in the backup.
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicate the current state of the backup.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The pending backup is still being created. Operations on the
    # backup will be rejected in this state.
    CREATING = 1

    # The backup is complete and ready to use.
    READY = 2

    # The backup is not available at this moment.
    NOT_AVAILABLE = 3
  end
end

#database_uid::String (readonly)

Returns Output only. The system-generated UUID4 for the Firestore database that the backup is from.

Returns:

  • (::String)

    Output only. The system-generated UUID4 for the Firestore database that the backup is from.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/firestore/admin/v1/backup.rb', line 64

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Backup specific statistics.
  # @!attribute [r] size_bytes
  #   @return [::Integer]
  #     Output only. Summation of the size of all documents and index entries in
  #     the backup, measured in bytes.
  # @!attribute [r] document_count
  #   @return [::Integer]
  #     Output only. The total number of documents contained in the backup.
  # @!attribute [r] index_count
  #   @return [::Integer]
  #     Output only. The total number of index entries contained in the backup.
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicate the current state of the backup.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The pending backup is still being created. Operations on the
    # backup will be rejected in this state.
    CREATING = 1

    # The backup is complete and ready to use.
    READY = 2

    # The backup is not available at this moment.
    NOT_AVAILABLE = 3
  end
end

#expire_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp at which this backup expires.

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/firestore/admin/v1/backup.rb', line 64

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Backup specific statistics.
  # @!attribute [r] size_bytes
  #   @return [::Integer]
  #     Output only. Summation of the size of all documents and index entries in
  #     the backup, measured in bytes.
  # @!attribute [r] document_count
  #   @return [::Integer]
  #     Output only. The total number of documents contained in the backup.
  # @!attribute [r] index_count
  #   @return [::Integer]
  #     Output only. The total number of index entries contained in the backup.
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicate the current state of the backup.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The pending backup is still being created. Operations on the
    # backup will be rejected in this state.
    CREATING = 1

    # The backup is complete and ready to use.
    READY = 2

    # The backup is not available at this moment.
    NOT_AVAILABLE = 3
  end
end

#name::String (readonly)

Returns Output only. The unique resource name of the Backup.

Format is projects/{project}/locations/{location}/backups/{backup}.

The location in the name will be the Standard Managed Multi-Region (SMMR) location (e.g. us) if the backup was created with an SMMR location, or the Google Managed Multi-Region (GMMR) location (e.g. nam5) if the backup was created with a GMMR location.

Returns:

  • (::String)

    Output only. The unique resource name of the Backup.

    Format is projects/{project}/locations/{location}/backups/{backup}.

    The location in the name will be the Standard Managed Multi-Region (SMMR) location (e.g. us) if the backup was created with an SMMR location, or the Google Managed Multi-Region (GMMR) location (e.g. nam5) if the backup was created with a GMMR location.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/firestore/admin/v1/backup.rb', line 64

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Backup specific statistics.
  # @!attribute [r] size_bytes
  #   @return [::Integer]
  #     Output only. Summation of the size of all documents and index entries in
  #     the backup, measured in bytes.
  # @!attribute [r] document_count
  #   @return [::Integer]
  #     Output only. The total number of documents contained in the backup.
  # @!attribute [r] index_count
  #   @return [::Integer]
  #     Output only. The total number of index entries contained in the backup.
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicate the current state of the backup.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The pending backup is still being created. Operations on the
    # backup will be rejected in this state.
    CREATING = 1

    # The backup is complete and ready to use.
    READY = 2

    # The backup is not available at this moment.
    NOT_AVAILABLE = 3
  end
end

#snapshot_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The backup contains an externally consistent copy of the database at this time.

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/firestore/admin/v1/backup.rb', line 64

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Backup specific statistics.
  # @!attribute [r] size_bytes
  #   @return [::Integer]
  #     Output only. Summation of the size of all documents and index entries in
  #     the backup, measured in bytes.
  # @!attribute [r] document_count
  #   @return [::Integer]
  #     Output only. The total number of documents contained in the backup.
  # @!attribute [r] index_count
  #   @return [::Integer]
  #     Output only. The total number of index entries contained in the backup.
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicate the current state of the backup.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The pending backup is still being created. Operations on the
    # backup will be rejected in this state.
    CREATING = 1

    # The backup is complete and ready to use.
    READY = 2

    # The backup is not available at this moment.
    NOT_AVAILABLE = 3
  end
end

#state::Google::Cloud::Firestore::Admin::V1::Backup::State (readonly)

Returns Output only. The current state of the backup.

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/firestore/admin/v1/backup.rb', line 64

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Backup specific statistics.
  # @!attribute [r] size_bytes
  #   @return [::Integer]
  #     Output only. Summation of the size of all documents and index entries in
  #     the backup, measured in bytes.
  # @!attribute [r] document_count
  #   @return [::Integer]
  #     Output only. The total number of documents contained in the backup.
  # @!attribute [r] index_count
  #   @return [::Integer]
  #     Output only. The total number of index entries contained in the backup.
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicate the current state of the backup.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The pending backup is still being created. Operations on the
    # backup will be rejected in this state.
    CREATING = 1

    # The backup is complete and ready to use.
    READY = 2

    # The backup is not available at this moment.
    NOT_AVAILABLE = 3
  end
end

#stats::Google::Cloud::Firestore::Admin::V1::Backup::Stats (readonly)

Returns Output only. Statistics about the backup.

This data only becomes available after the backup is fully materialized to secondary storage. This field will be empty till then.

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/firestore/admin/v1/backup.rb', line 64

class Backup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Backup specific statistics.
  # @!attribute [r] size_bytes
  #   @return [::Integer]
  #     Output only. Summation of the size of all documents and index entries in
  #     the backup, measured in bytes.
  # @!attribute [r] document_count
  #   @return [::Integer]
  #     Output only. The total number of documents contained in the backup.
  # @!attribute [r] index_count
  #   @return [::Integer]
  #     Output only. The total number of index entries contained in the backup.
  class Stats
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicate the current state of the backup.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The pending backup is still being created. Operations on the
    # backup will be rejected in this state.
    CREATING = 1

    # The backup is complete and ready to use.
    READY = 2

    # The backup is not available at this moment.
    NOT_AVAILABLE = 3
  end
end