Class: Google::Cloud::Firestore::Admin::V1::CloneDatabaseMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::CloneDatabaseMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/operation.rb
Overview
Metadata for the long-running operation from the [CloneDatabase][google.firestore.admin.v1.CloneDatabase] request.
Instance Attribute Summary collapse
-
#database ⇒ ::String
The name of the database being cloned to.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
The time the clone finished, unset for ongoing clones.
-
#operation_state ⇒ ::Google::Cloud::Firestore::Admin::V1::OperationState
The operation state of the clone.
-
#pitr_snapshot ⇒ ::Google::Cloud::Firestore::Admin::V1::PitrSnapshot
The snapshot from which this database was cloned.
-
#progress_percentage ⇒ ::Google::Cloud::Firestore::Admin::V1::Progress
How far along the clone is as an estimated percentage of remaining time.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The time the clone was started.
Instance Attribute Details
#database ⇒ ::String
Returns The name of the database being cloned to.
298 299 300 301 |
# File 'proto_docs/google/firestore/admin/v1/operation.rb', line 298 class CloneDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the clone finished, unset for ongoing clones.
298 299 300 301 |
# File 'proto_docs/google/firestore/admin/v1/operation.rb', line 298 class CloneDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#operation_state ⇒ ::Google::Cloud::Firestore::Admin::V1::OperationState
Returns The operation state of the clone.
298 299 300 301 |
# File 'proto_docs/google/firestore/admin/v1/operation.rb', line 298 class CloneDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pitr_snapshot ⇒ ::Google::Cloud::Firestore::Admin::V1::PitrSnapshot
Returns The snapshot from which this database was cloned.
298 299 300 301 |
# File 'proto_docs/google/firestore/admin/v1/operation.rb', line 298 class CloneDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#progress_percentage ⇒ ::Google::Cloud::Firestore::Admin::V1::Progress
Returns How far along the clone is as an estimated percentage of remaining time.
298 299 300 301 |
# File 'proto_docs/google/firestore/admin/v1/operation.rb', line 298 class CloneDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the clone was started.
298 299 300 301 |
# File 'proto_docs/google/firestore/admin/v1/operation.rb', line 298 class CloneDatabaseMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |