Class: Google::Cloud::Firestore::Admin::V1::ExportDocumentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::ExportDocumentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/firestore_admin.rb
Overview
The request for FirestoreAdmin.ExportDocuments.
Instance Attribute Summary collapse
-
#collection_ids ⇒ ::Array<::String>
IDs of the collection groups to export.
-
#name ⇒ ::String
Required.
-
#namespace_ids ⇒ ::Array<::String>
An empty list represents all namespaces.
-
#output_uri_prefix ⇒ ::String
The output URI.
-
#snapshot_time ⇒ ::Google::Protobuf::Timestamp
The timestamp that corresponds to the version of the database to be exported.
Instance Attribute Details
#collection_ids ⇒ ::Array<::String>
Returns IDs of the collection groups to export. Unspecified means all collection groups. Each collection group in this list must be unique.
489 490 491 492 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 489 class ExportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Database to export. Should be of the form:
projects/{project_id}/databases/{database_id}.
489 490 491 492 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 489 class ExportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#namespace_ids ⇒ ::Array<::String>
Returns An empty list represents all namespaces. This is the preferred usage for databases that don't use namespaces.
An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn't want to include them. Each namespace in this list must be unique.
489 490 491 492 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 489 class ExportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_uri_prefix ⇒ ::String
Returns The output URI. Currently only supports Google Cloud Storage URIs of the
form: gs://BUCKET_NAME[/NAMESPACE_PATH], where BUCKET_NAME is the name
of the Google Cloud Storage bucket and NAMESPACE_PATH is an optional
Google Cloud Storage namespace path. When
choosing a name, be sure to consider Google Cloud Storage naming
guidelines: https://cloud.google.com/storage/docs/naming.
If the URI is a bucket (without a namespace path), a prefix will be
generated based on the start time.
489 490 491 492 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 489 class ExportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#snapshot_time ⇒ ::Google::Protobuf::Timestamp
Returns The timestamp that corresponds to the version of the database to be exported. The timestamp must be in the past, rounded to the minute and not older than earliestVersionTime. If specified, then the exported documents will represent a consistent view of the database at the provided time. Otherwise, there are no guarantees about the consistency of the exported documents.
489 490 491 492 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 489 class ExportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |