Class: Google::Cloud::Firestore::Admin::V1::Index::IndexField

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/firestore/admin/v1/index.rb

Overview

A field in an index. The field_path describes which field is indexed, the value_mode describes how the field value is indexed.

Defined Under Namespace

Modules: ArrayConfig, Order Classes: SearchConfig, VectorConfig

Instance Attribute Summary collapse

Instance Attribute Details

#array_config::Google::Cloud::Firestore::Admin::V1::Index::IndexField::ArrayConfig

Returns Indicates that this field supports operations on array_values.

Note: The following fields are mutually exclusive: array_config, order, vector_config, search_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 122

class IndexField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The index configuration to support vector search operations
  # @!attribute [rw] dimension
  #   @return [::Integer]
  #     Required. The vector dimension this configuration applies to.
  #
  #     The resulting index will only include vectors of this dimension, and
  #     can be used for vector search with the same dimension.
  # @!attribute [rw] flat
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex]
  #     Indicates the vector index is a flat index.
  class VectorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # An index that stores vectors in a flat data structure, and supports
    # exhaustive search.
    class FlatIndex
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The configuration for how to index a field for search.
  # @!attribute [rw] text_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextSpec]
  #     Optional. The specification for building a text search index for a
  #     field.
  # @!attribute [rw] geo_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchGeoSpec]
  #     Optional. The specification for building a geo search index for a
  #     field.
  class SearchConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specification of how the field should be indexed for search text
    # indexes.
    # @!attribute [rw] index_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextIndexType]
    #     Required. How to index the text field value.
    # @!attribute [rw] match_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextMatchType]
    #     Required. How to match the text field value.
    class SearchTextIndexSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a text search index for a field.
    # @!attribute [rw] index_specs
    #   @return [::Array<::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextIndexSpec>]
    #     Required. Specifications for how the field should be indexed.
    #     Repeated so that the field can be indexed in multiple ways.
    class SearchTextSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a geo search index for a field.
    # @!attribute [rw] geo_json_indexing_disabled
    #   @return [::Boolean]
    #     Optional. Disables geoJSON indexing for the field. By default,
    #     geoJSON points are indexed.
    class SearchGeoSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Ways to index the text field value.
    module TextIndexType
      # The index type is unspecified. Not a valid option.
      TEXT_INDEX_TYPE_UNSPECIFIED = 0

      # Field values are tokenized. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      TOKENIZED = 1
    end

    # Types of text matches that are supported for the
    # field.
    module TextMatchType
      # The match type is unspecified. Not a valid option.
      TEXT_MATCH_TYPE_UNSPECIFIED = 0

      # Match on any indexed field. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      MATCH_GLOBALLY = 1
    end
  end

  # The supported orderings.
  module Order
    # The ordering is unspecified. Not a valid option.
    ORDER_UNSPECIFIED = 0

    # The field is ordered by ascending field value.
    ASCENDING = 1

    # The field is ordered by descending field value.
    DESCENDING = 2
  end

  # The supported array value configurations.
  module ArrayConfig
    # The index does not support additional array queries.
    ARRAY_CONFIG_UNSPECIFIED = 0

    # The index supports array containment queries.
    CONTAINS = 1
  end
end

#field_path::String

Returns Can be name. For single field indexes, this must match the name of the field or may be omitted.

Returns:

  • (::String)

    Can be name. For single field indexes, this must match the name of the field or may be omitted.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 122

class IndexField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The index configuration to support vector search operations
  # @!attribute [rw] dimension
  #   @return [::Integer]
  #     Required. The vector dimension this configuration applies to.
  #
  #     The resulting index will only include vectors of this dimension, and
  #     can be used for vector search with the same dimension.
  # @!attribute [rw] flat
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex]
  #     Indicates the vector index is a flat index.
  class VectorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # An index that stores vectors in a flat data structure, and supports
    # exhaustive search.
    class FlatIndex
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The configuration for how to index a field for search.
  # @!attribute [rw] text_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextSpec]
  #     Optional. The specification for building a text search index for a
  #     field.
  # @!attribute [rw] geo_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchGeoSpec]
  #     Optional. The specification for building a geo search index for a
  #     field.
  class SearchConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specification of how the field should be indexed for search text
    # indexes.
    # @!attribute [rw] index_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextIndexType]
    #     Required. How to index the text field value.
    # @!attribute [rw] match_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextMatchType]
    #     Required. How to match the text field value.
    class SearchTextIndexSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a text search index for a field.
    # @!attribute [rw] index_specs
    #   @return [::Array<::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextIndexSpec>]
    #     Required. Specifications for how the field should be indexed.
    #     Repeated so that the field can be indexed in multiple ways.
    class SearchTextSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a geo search index for a field.
    # @!attribute [rw] geo_json_indexing_disabled
    #   @return [::Boolean]
    #     Optional. Disables geoJSON indexing for the field. By default,
    #     geoJSON points are indexed.
    class SearchGeoSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Ways to index the text field value.
    module TextIndexType
      # The index type is unspecified. Not a valid option.
      TEXT_INDEX_TYPE_UNSPECIFIED = 0

      # Field values are tokenized. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      TOKENIZED = 1
    end

    # Types of text matches that are supported for the
    # field.
    module TextMatchType
      # The match type is unspecified. Not a valid option.
      TEXT_MATCH_TYPE_UNSPECIFIED = 0

      # Match on any indexed field. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      MATCH_GLOBALLY = 1
    end
  end

  # The supported orderings.
  module Order
    # The ordering is unspecified. Not a valid option.
    ORDER_UNSPECIFIED = 0

    # The field is ordered by ascending field value.
    ASCENDING = 1

    # The field is ordered by descending field value.
    DESCENDING = 2
  end

  # The supported array value configurations.
  module ArrayConfig
    # The index does not support additional array queries.
    ARRAY_CONFIG_UNSPECIFIED = 0

    # The index supports array containment queries.
    CONTAINS = 1
  end
end

#order::Google::Cloud::Firestore::Admin::V1::Index::IndexField::Order

Returns Indicates that this field supports ordering by the specified order or comparing using =, !=, <, <=, >, >=.

Note: The following fields are mutually exclusive: order, array_config, vector_config, search_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Firestore::Admin::V1::Index::IndexField::Order)

    Indicates that this field supports ordering by the specified order or comparing using =, !=, <, <=, >, >=.

    Note: The following fields are mutually exclusive: order, array_config, vector_config, search_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 122

class IndexField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The index configuration to support vector search operations
  # @!attribute [rw] dimension
  #   @return [::Integer]
  #     Required. The vector dimension this configuration applies to.
  #
  #     The resulting index will only include vectors of this dimension, and
  #     can be used for vector search with the same dimension.
  # @!attribute [rw] flat
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex]
  #     Indicates the vector index is a flat index.
  class VectorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # An index that stores vectors in a flat data structure, and supports
    # exhaustive search.
    class FlatIndex
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The configuration for how to index a field for search.
  # @!attribute [rw] text_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextSpec]
  #     Optional. The specification for building a text search index for a
  #     field.
  # @!attribute [rw] geo_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchGeoSpec]
  #     Optional. The specification for building a geo search index for a
  #     field.
  class SearchConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specification of how the field should be indexed for search text
    # indexes.
    # @!attribute [rw] index_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextIndexType]
    #     Required. How to index the text field value.
    # @!attribute [rw] match_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextMatchType]
    #     Required. How to match the text field value.
    class SearchTextIndexSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a text search index for a field.
    # @!attribute [rw] index_specs
    #   @return [::Array<::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextIndexSpec>]
    #     Required. Specifications for how the field should be indexed.
    #     Repeated so that the field can be indexed in multiple ways.
    class SearchTextSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a geo search index for a field.
    # @!attribute [rw] geo_json_indexing_disabled
    #   @return [::Boolean]
    #     Optional. Disables geoJSON indexing for the field. By default,
    #     geoJSON points are indexed.
    class SearchGeoSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Ways to index the text field value.
    module TextIndexType
      # The index type is unspecified. Not a valid option.
      TEXT_INDEX_TYPE_UNSPECIFIED = 0

      # Field values are tokenized. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      TOKENIZED = 1
    end

    # Types of text matches that are supported for the
    # field.
    module TextMatchType
      # The match type is unspecified. Not a valid option.
      TEXT_MATCH_TYPE_UNSPECIFIED = 0

      # Match on any indexed field. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      MATCH_GLOBALLY = 1
    end
  end

  # The supported orderings.
  module Order
    # The ordering is unspecified. Not a valid option.
    ORDER_UNSPECIFIED = 0

    # The field is ordered by ascending field value.
    ASCENDING = 1

    # The field is ordered by descending field value.
    DESCENDING = 2
  end

  # The supported array value configurations.
  module ArrayConfig
    # The index does not support additional array queries.
    ARRAY_CONFIG_UNSPECIFIED = 0

    # The index supports array containment queries.
    CONTAINS = 1
  end
end

#search_config::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig

Returns Indicates that this field supports search operations. This field is only currently supported for indexes with MONGODB_COMPATIBLE_API ApiScope.

Note: The following fields are mutually exclusive: search_config, order, array_config, vector_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig)

    Indicates that this field supports search operations. This field is only currently supported for indexes with MONGODB_COMPATIBLE_API ApiScope.

    Note: The following fields are mutually exclusive: search_config, order, array_config, vector_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 122

class IndexField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The index configuration to support vector search operations
  # @!attribute [rw] dimension
  #   @return [::Integer]
  #     Required. The vector dimension this configuration applies to.
  #
  #     The resulting index will only include vectors of this dimension, and
  #     can be used for vector search with the same dimension.
  # @!attribute [rw] flat
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex]
  #     Indicates the vector index is a flat index.
  class VectorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # An index that stores vectors in a flat data structure, and supports
    # exhaustive search.
    class FlatIndex
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The configuration for how to index a field for search.
  # @!attribute [rw] text_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextSpec]
  #     Optional. The specification for building a text search index for a
  #     field.
  # @!attribute [rw] geo_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchGeoSpec]
  #     Optional. The specification for building a geo search index for a
  #     field.
  class SearchConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specification of how the field should be indexed for search text
    # indexes.
    # @!attribute [rw] index_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextIndexType]
    #     Required. How to index the text field value.
    # @!attribute [rw] match_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextMatchType]
    #     Required. How to match the text field value.
    class SearchTextIndexSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a text search index for a field.
    # @!attribute [rw] index_specs
    #   @return [::Array<::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextIndexSpec>]
    #     Required. Specifications for how the field should be indexed.
    #     Repeated so that the field can be indexed in multiple ways.
    class SearchTextSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a geo search index for a field.
    # @!attribute [rw] geo_json_indexing_disabled
    #   @return [::Boolean]
    #     Optional. Disables geoJSON indexing for the field. By default,
    #     geoJSON points are indexed.
    class SearchGeoSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Ways to index the text field value.
    module TextIndexType
      # The index type is unspecified. Not a valid option.
      TEXT_INDEX_TYPE_UNSPECIFIED = 0

      # Field values are tokenized. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      TOKENIZED = 1
    end

    # Types of text matches that are supported for the
    # field.
    module TextMatchType
      # The match type is unspecified. Not a valid option.
      TEXT_MATCH_TYPE_UNSPECIFIED = 0

      # Match on any indexed field. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      MATCH_GLOBALLY = 1
    end
  end

  # The supported orderings.
  module Order
    # The ordering is unspecified. Not a valid option.
    ORDER_UNSPECIFIED = 0

    # The field is ordered by ascending field value.
    ASCENDING = 1

    # The field is ordered by descending field value.
    DESCENDING = 2
  end

  # The supported array value configurations.
  module ArrayConfig
    # The index does not support additional array queries.
    ARRAY_CONFIG_UNSPECIFIED = 0

    # The index supports array containment queries.
    CONTAINS = 1
  end
end

#vector_config::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig

Returns Indicates that this field supports nearest neighbor and distance operations on vector.

Note: The following fields are mutually exclusive: vector_config, order, array_config, search_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig)

    Indicates that this field supports nearest neighbor and distance operations on vector.

    Note: The following fields are mutually exclusive: vector_config, order, array_config, search_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 122

class IndexField
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The index configuration to support vector search operations
  # @!attribute [rw] dimension
  #   @return [::Integer]
  #     Required. The vector dimension this configuration applies to.
  #
  #     The resulting index will only include vectors of this dimension, and
  #     can be used for vector search with the same dimension.
  # @!attribute [rw] flat
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex]
  #     Indicates the vector index is a flat index.
  class VectorConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # An index that stores vectors in a flat data structure, and supports
    # exhaustive search.
    class FlatIndex
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end

  # The configuration for how to index a field for search.
  # @!attribute [rw] text_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextSpec]
  #     Optional. The specification for building a text search index for a
  #     field.
  # @!attribute [rw] geo_spec
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchGeoSpec]
  #     Optional. The specification for building a geo search index for a
  #     field.
  class SearchConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Specification of how the field should be indexed for search text
    # indexes.
    # @!attribute [rw] index_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextIndexType]
    #     Required. How to index the text field value.
    # @!attribute [rw] match_type
    #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextMatchType]
    #     Required. How to match the text field value.
    class SearchTextIndexSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a text search index for a field.
    # @!attribute [rw] index_specs
    #   @return [::Array<::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextIndexSpec>]
    #     Required. Specifications for how the field should be indexed.
    #     Repeated so that the field can be indexed in multiple ways.
    class SearchTextSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # The specification for how to build a geo search index for a field.
    # @!attribute [rw] geo_json_indexing_disabled
    #   @return [::Boolean]
    #     Optional. Disables geoJSON indexing for the field. By default,
    #     geoJSON points are indexed.
    class SearchGeoSpec
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end

    # Ways to index the text field value.
    module TextIndexType
      # The index type is unspecified. Not a valid option.
      TEXT_INDEX_TYPE_UNSPECIFIED = 0

      # Field values are tokenized. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      TOKENIZED = 1
    end

    # Types of text matches that are supported for the
    # field.
    module TextMatchType
      # The match type is unspecified. Not a valid option.
      TEXT_MATCH_TYPE_UNSPECIFIED = 0

      # Match on any indexed field. This is the only way currently supported
      # for MONGODB_COMPATIBLE_API.
      MATCH_GLOBALLY = 1
    end
  end

  # The supported orderings.
  module Order
    # The ordering is unspecified. Not a valid option.
    ORDER_UNSPECIFIED = 0

    # The field is ordered by ascending field value.
    ASCENDING = 1

    # The field is ordered by descending field value.
    DESCENDING = 2
  end

  # The supported array value configurations.
  module ArrayConfig
    # The index does not support additional array queries.
    ARRAY_CONFIG_UNSPECIFIED = 0

    # The index supports array containment queries.
    CONTAINS = 1
  end
end