Class: Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/firestore/admin/v1/index.rb

Overview

The configuration for how to index a field for search.

Defined Under Namespace

Modules: TextIndexType, TextMatchType Classes: SearchGeoSpec, SearchTextIndexSpec, SearchTextSpec

Instance Attribute Summary collapse

Instance Attribute Details

#geo_spec::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchGeoSpec

Returns Optional. The specification for building a geo search index for a field.

Returns:



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 157

class SearchConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specification of how the field should be indexed for search text
  # indexes.
  # @!attribute [rw] index_type
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextIndexType]
  #     Required. How to index the text field value.
  # @!attribute [rw] match_type
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextMatchType]
  #     Required. How to match the text field value.
  class SearchTextIndexSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The specification for how to build a text search index for a field.
  # @!attribute [rw] index_specs
  #   @return [::Array<::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextIndexSpec>]
  #     Required. Specifications for how the field should be indexed.
  #     Repeated so that the field can be indexed in multiple ways.
  class SearchTextSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The specification for how to build a geo search index for a field.
  # @!attribute [rw] geo_json_indexing_disabled
  #   @return [::Boolean]
  #     Optional. Disables geoJSON indexing for the field. By default,
  #     geoJSON points are indexed.
  class SearchGeoSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Ways to index the text field value.
  module TextIndexType
    # The index type is unspecified. Not a valid option.
    TEXT_INDEX_TYPE_UNSPECIFIED = 0

    # Field values are tokenized. This is the only way currently supported
    # for MONGODB_COMPATIBLE_API.
    TOKENIZED = 1
  end

  # Types of text matches that are supported for the
  # field.
  module TextMatchType
    # The match type is unspecified. Not a valid option.
    TEXT_MATCH_TYPE_UNSPECIFIED = 0

    # Match on any indexed field. This is the only way currently supported
    # for MONGODB_COMPATIBLE_API.
    MATCH_GLOBALLY = 1
  end
end

#text_spec::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextSpec

Returns Optional. The specification for building a text search index for a field.

Returns:



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 157

class SearchConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specification of how the field should be indexed for search text
  # indexes.
  # @!attribute [rw] index_type
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextIndexType]
  #     Required. How to index the text field value.
  # @!attribute [rw] match_type
  #   @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::TextMatchType]
  #     Required. How to match the text field value.
  class SearchTextIndexSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The specification for how to build a text search index for a field.
  # @!attribute [rw] index_specs
  #   @return [::Array<::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextIndexSpec>]
  #     Required. Specifications for how the field should be indexed.
  #     Repeated so that the field can be indexed in multiple ways.
  class SearchTextSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The specification for how to build a geo search index for a field.
  # @!attribute [rw] geo_json_indexing_disabled
  #   @return [::Boolean]
  #     Optional. Disables geoJSON indexing for the field. By default,
  #     geoJSON points are indexed.
  class SearchGeoSpec
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Ways to index the text field value.
  module TextIndexType
    # The index type is unspecified. Not a valid option.
    TEXT_INDEX_TYPE_UNSPECIFIED = 0

    # Field values are tokenized. This is the only way currently supported
    # for MONGODB_COMPATIBLE_API.
    TOKENIZED = 1
  end

  # Types of text matches that are supported for the
  # field.
  module TextMatchType
    # The match type is unspecified. Not a valid option.
    TEXT_MATCH_TYPE_UNSPECIFIED = 0

    # Match on any indexed field. This is the only way currently supported
    # for MONGODB_COMPATIBLE_API.
    MATCH_GLOBALLY = 1
  end
end