Class: Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/firestore/admin/v1/index.rb

Overview

The specification for how to build a text search index for a field.

Instance Attribute Summary collapse

Instance Attribute Details

#index_specs::Array<::Google::Cloud::Firestore::Admin::V1::Index::IndexField::SearchConfig::SearchTextIndexSpec>

Returns Required. Specifications for how the field should be indexed. Repeated so that the field can be indexed in multiple ways.

Returns:



179
180
181
182
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 179

class SearchTextSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end