Class: Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/index.rb
Overview
The index configuration to support vector search operations
Defined Under Namespace
Classes: FlatIndex
Instance Attribute Summary collapse
-
#dimension ⇒ ::Integer
Required.
-
#flat ⇒ ::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex
Indicates the vector index is a flat index.
Instance Attribute Details
#dimension ⇒ ::Integer
Returns Required. The vector dimension this configuration applies to.
The resulting index will only include vectors of this dimension, and can be used for vector search with the same dimension.
136 137 138 139 140 141 142 143 144 145 146 |
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 136 class VectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An index that stores vectors in a flat data structure, and supports # exhaustive search. class FlatIndex include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#flat ⇒ ::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex
Returns Indicates the vector index is a flat index.
136 137 138 139 140 141 142 143 144 145 146 |
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 136 class VectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An index that stores vectors in a flat data structure, and supports # exhaustive search. class FlatIndex include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |