Class: Google::Cloud::Firestore::Admin::V1::PitrSnapshot

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/firestore/admin/v1/snapshot.rb

Overview

A consistent snapshot of a database at a specific point in time. A PITR (Point-in-time recovery) snapshot with previous versions of a database's data is available for every minute up to the associated database's data retention period. If the PITR feature is enabled, the retention period is 7 days; otherwise, it is one hour.

Instance Attribute Summary collapse

Instance Attribute Details

#database::String

Returns Required. The name of the database that this was a snapshot of. Format: projects/{project}/databases/{database}.

Returns:

  • (::String)

    Required. The name of the database that this was a snapshot of. Format: projects/{project}/databases/{database}.



40
41
42
43
# File 'proto_docs/google/firestore/admin/v1/snapshot.rb', line 40

class PitrSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#database_uid::String (readonly)

Returns Output only. Public UUID of the database the snapshot was associated with.

Returns:

  • (::String)

    Output only. Public UUID of the database the snapshot was associated with.



40
41
42
43
# File 'proto_docs/google/firestore/admin/v1/snapshot.rb', line 40

class PitrSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#snapshot_time::Google::Protobuf::Timestamp

Returns Required. Snapshot time of the database.

Returns:



40
41
42
43
# File 'proto_docs/google/firestore/admin/v1/snapshot.rb', line 40

class PitrSnapshot
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end