Class: Google::Cloud::Firestore::Admin::V1::RestoreDatabaseRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::RestoreDatabaseRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/firestore_admin.rb
Overview
The request message for FirestoreAdmin.RestoreDatabase.
Defined Under Namespace
Classes: TagsEntry
Instance Attribute Summary collapse
-
#backup ⇒ ::String
Required.
-
#database_id ⇒ ::String
Required.
-
#encryption_config ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig
Optional.
-
#parent ⇒ ::String
Required.
-
#tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
Instance Attribute Details
#backup ⇒ ::String
Returns Required. Backup to restore from. Must be from the same project as the parent.
The restored database will be created in the same location as the source backup.
Format is: projects/{project_id}/locations/{location}/backups/{backup}.
679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 679 class RestoreDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#database_id ⇒ ::String
Returns Required. The ID to use for the database, which will become the final component of the database's resource name. This database ID must not be associated with an existing database.
This value should be 4-63 characters. Valid characters are /[a-z][0-9]-/ with first character a letter and the last a letter or a number. Must not be UUID-like /[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}/.
"(default)" database ID is also valid if the database is Standard edition.
679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 679 class RestoreDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#encryption_config ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig
Returns Optional. Encryption configuration for the restored database.
If this field is not specified, the restored database will use the same encryption configuration as the backup, namely use_source_encryption.
679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 679 class RestoreDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#parent ⇒ ::String
Returns Required. The project to restore the database in. Format is
projects/{project_id}.
679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 679 class RestoreDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Immutable. Tags to be bound to the restored database.
The tags should be provided in the format of
tagKeys/{tag_key_id} -> tagValues/{tag_value_id}.
679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 679 class RestoreDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |