Class: Google::Cloud::Firestore::Admin::V1::CloneDatabaseRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::CloneDatabaseRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/firestore_admin.rb
Overview
The request message for FirestoreAdmin.CloneDatabase.
Defined Under Namespace
Classes: TagsEntry
Instance Attribute Summary collapse
-
#database_id ⇒ ::String
Required.
-
#encryption_config ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig
Optional.
-
#parent ⇒ ::String
Required.
-
#pitr_snapshot ⇒ ::Google::Cloud::Firestore::Admin::V1::PitrSnapshot
Required.
-
#tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
Instance Attribute Details
#database_id ⇒ ::String
Returns Required. The ID to use for the database, which will become the final component of the database's resource name. This database ID must not be associated with an existing database.
This value should be 4-63 characters. Valid characters are /[a-z][0-9]-/ with first character a letter and the last a letter or a number. Must not be UUID-like /[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}/.
"(default)" database ID is also valid if the database is Standard edition.
730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 730 class CloneDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#encryption_config ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig
Returns Optional. Encryption configuration for the cloned database.
If this field is not specified, the cloned database will use the same encryption configuration as the source database, namely use_source_encryption.
730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 730 class CloneDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#parent ⇒ ::String
Returns Required. The project to clone the database in. Format is
projects/{project_id}.
730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 730 class CloneDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pitr_snapshot ⇒ ::Google::Cloud::Firestore::Admin::V1::PitrSnapshot
Returns Required. Specification of the PITR data to clone from. The source database must exist.
The cloned database will be created in the same location as the source database.
730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 730 class CloneDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#tags ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Immutable. Tags to be bound to the cloned database.
The tags should be provided in the format of
tagKeys/{tag_key_id} -> tagValues/{tag_value_id}.
730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 730 class CloneDatabaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class TagsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |