Class: Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/database.rb
Overview
Encryption configuration for a new database being created from another source.
The source could be a Backup or a PitrSnapshot.
Defined Under Namespace
Classes: CustomerManagedEncryptionOptions, GoogleDefaultEncryptionOptions, SourceEncryptionOptions
Instance Attribute Summary collapse
-
#customer_managed_encryption ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig::CustomerManagedEncryptionOptions
Use Customer Managed Encryption Keys (CMEK) for encryption.
-
#google_default_encryption ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig::GoogleDefaultEncryptionOptions
Use Google default encryption.
-
#use_source_encryption ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig::SourceEncryptionOptions
The database will use the same encryption configuration as the source.
Instance Attribute Details
#customer_managed_encryption ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig::CustomerManagedEncryptionOptions
Returns Use Customer Managed Encryption Keys (CMEK) for encryption.
Note: The following fields are mutually exclusive: customer_managed_encryption, google_default_encryption, use_source_encryption. If a field in that set is populated, all other fields in the set will automatically be cleared.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'proto_docs/google/firestore/admin/v1/database.rb', line 233 class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration options for using Google default encryption. class GoogleDefaultEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration options for using the same encryption method as the # source. class SourceEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration options for using CMEK (Customer Managed Encryption # Key) encryption. # @!attribute [rw] kms_key_name # @return [::String] # Required. Only keys in the same location as the database are allowed to # be used for encryption. # # For Firestore's nam5 multi-region, this corresponds to Cloud KMS # multi-region us. For Firestore's eur3 multi-region, this corresponds to # Cloud KMS multi-region europe. See # https://cloud.google.com/kms/docs/locations. # # The expected format is # `projects/{project_id}/locations/{kms_location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}`. class CustomerManagedEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#google_default_encryption ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig::GoogleDefaultEncryptionOptions
Returns Use Google default encryption.
Note: The following fields are mutually exclusive: google_default_encryption, use_source_encryption, customer_managed_encryption. If a field in that set is populated, all other fields in the set will automatically be cleared.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'proto_docs/google/firestore/admin/v1/database.rb', line 233 class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration options for using Google default encryption. class GoogleDefaultEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration options for using the same encryption method as the # source. class SourceEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration options for using CMEK (Customer Managed Encryption # Key) encryption. # @!attribute [rw] kms_key_name # @return [::String] # Required. Only keys in the same location as the database are allowed to # be used for encryption. # # For Firestore's nam5 multi-region, this corresponds to Cloud KMS # multi-region us. For Firestore's eur3 multi-region, this corresponds to # Cloud KMS multi-region europe. See # https://cloud.google.com/kms/docs/locations. # # The expected format is # `projects/{project_id}/locations/{kms_location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}`. class CustomerManagedEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#use_source_encryption ⇒ ::Google::Cloud::Firestore::Admin::V1::Database::EncryptionConfig::SourceEncryptionOptions
Returns The database will use the same encryption configuration as the source.
Note: The following fields are mutually exclusive: use_source_encryption, google_default_encryption, customer_managed_encryption. If a field in that set is populated, all other fields in the set will automatically be cleared.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'proto_docs/google/firestore/admin/v1/database.rb', line 233 class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The configuration options for using Google default encryption. class GoogleDefaultEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration options for using the same encryption method as the # source. class SourceEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The configuration options for using CMEK (Customer Managed Encryption # Key) encryption. # @!attribute [rw] kms_key_name # @return [::String] # Required. Only keys in the same location as the database are allowed to # be used for encryption. # # For Firestore's nam5 multi-region, this corresponds to Cloud KMS # multi-region us. For Firestore's eur3 multi-region, this corresponds to # Cloud KMS multi-region europe. See # https://cloud.google.com/kms/docs/locations. # # The expected format is # `projects/{project_id}/locations/{kms_location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}`. class CustomerManagedEncryptionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |