Class: Google::Cloud::Firestore::Admin::V1::ImportDocumentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::ImportDocumentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/firestore_admin.rb
Overview
The request for FirestoreAdmin.ImportDocuments.
Instance Attribute Summary collapse
-
#collection_ids ⇒ ::Array<::String>
IDs of the collection groups to import.
-
#input_uri_prefix ⇒ ::String
Location of the exported files.
-
#name ⇒ ::String
Required.
-
#namespace_ids ⇒ ::Array<::String>
An empty list represents all namespaces.
Instance Attribute Details
#collection_ids ⇒ ::Array<::String>
Returns IDs of the collection groups to import. Unspecified means all collection groups that were included in the export. Each collection group in this list must be unique.
520 521 522 523 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 520 class ImportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#input_uri_prefix ⇒ ::String
Returns Location of the exported files. This must match the output_uri_prefix of an ExportDocumentsResponse from an export that has completed successfully. See: google.firestore.admin.v1.ExportDocumentsResponse.output_uri_prefix.
520 521 522 523 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 520 class ImportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Database to import into. Should be of the form:
projects/{project_id}/databases/{database_id}.
520 521 522 523 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 520 class ImportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#namespace_ids ⇒ ::Array<::String>
Returns An empty list represents all namespaces. This is the preferred usage for databases that don't use namespaces.
An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn't want to include them. Each namespace in this list must be unique.
520 521 522 523 |
# File 'proto_docs/google/firestore/admin/v1/firestore_admin.rb', line 520 class ImportDocumentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |