Class: Google::Cloud::Firestore::Admin::V1::Index::IndexField
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::Index::IndexField
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/index.rb
Overview
A field in an index. The field_path describes which field is indexed, the value_mode describes how the field value is indexed.
Defined Under Namespace
Modules: ArrayConfig, Order Classes: VectorConfig
Instance Attribute Summary collapse
-
#array_config ⇒ ::Google::Cloud::Firestore::Admin::V1::Index::IndexField::ArrayConfig
Indicates that this field supports operations on
array_values. -
#field_path ⇒ ::String
Can be name.
-
#order ⇒ ::Google::Cloud::Firestore::Admin::V1::Index::IndexField::Order
Indicates that this field supports ordering by the specified order or comparing using =, !=, <, <=, >, >=.
-
#vector_config ⇒ ::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig
Indicates that this field supports nearest neighbor and distance operations on vector.
Instance Attribute Details
#array_config ⇒ ::Google::Cloud::Firestore::Admin::V1::Index::IndexField::ArrayConfig
Returns Indicates that this field supports operations on array_values.
Note: The following fields are mutually exclusive: array_config, order, vector_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 110 class IndexField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The index configuration to support vector search operations # @!attribute [rw] dimension # @return [::Integer] # Required. The vector dimension this configuration applies to. # # The resulting index will only include vectors of this dimension, and # can be used for vector search with the same dimension. # @!attribute [rw] flat # @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex] # Indicates the vector index is a flat index. class VectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An index that stores vectors in a flat data structure, and supports # exhaustive search. class FlatIndex include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The supported orderings. module Order # The ordering is unspecified. Not a valid option. ORDER_UNSPECIFIED = 0 # The field is ordered by ascending field value. ASCENDING = 1 # The field is ordered by descending field value. DESCENDING = 2 end # The supported array value configurations. module ArrayConfig # The index does not support additional array queries. ARRAY_CONFIG_UNSPECIFIED = 0 # The index supports array containment queries. CONTAINS = 1 end end |
#field_path ⇒ ::String
Returns Can be name. For single field indexes, this must match the name of the field or may be omitted.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 110 class IndexField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The index configuration to support vector search operations # @!attribute [rw] dimension # @return [::Integer] # Required. The vector dimension this configuration applies to. # # The resulting index will only include vectors of this dimension, and # can be used for vector search with the same dimension. # @!attribute [rw] flat # @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex] # Indicates the vector index is a flat index. class VectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An index that stores vectors in a flat data structure, and supports # exhaustive search. class FlatIndex include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The supported orderings. module Order # The ordering is unspecified. Not a valid option. ORDER_UNSPECIFIED = 0 # The field is ordered by ascending field value. ASCENDING = 1 # The field is ordered by descending field value. DESCENDING = 2 end # The supported array value configurations. module ArrayConfig # The index does not support additional array queries. ARRAY_CONFIG_UNSPECIFIED = 0 # The index supports array containment queries. CONTAINS = 1 end end |
#order ⇒ ::Google::Cloud::Firestore::Admin::V1::Index::IndexField::Order
Returns Indicates that this field supports ordering by the specified order or comparing using =, !=, <, <=, >, >=.
Note: The following fields are mutually exclusive: order, array_config, vector_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 110 class IndexField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The index configuration to support vector search operations # @!attribute [rw] dimension # @return [::Integer] # Required. The vector dimension this configuration applies to. # # The resulting index will only include vectors of this dimension, and # can be used for vector search with the same dimension. # @!attribute [rw] flat # @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex] # Indicates the vector index is a flat index. class VectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An index that stores vectors in a flat data structure, and supports # exhaustive search. class FlatIndex include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The supported orderings. module Order # The ordering is unspecified. Not a valid option. ORDER_UNSPECIFIED = 0 # The field is ordered by ascending field value. ASCENDING = 1 # The field is ordered by descending field value. DESCENDING = 2 end # The supported array value configurations. module ArrayConfig # The index does not support additional array queries. ARRAY_CONFIG_UNSPECIFIED = 0 # The index supports array containment queries. CONTAINS = 1 end end |
#vector_config ⇒ ::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig
Returns Indicates that this field supports nearest neighbor and distance operations on vector.
Note: The following fields are mutually exclusive: vector_config, order, array_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 110 class IndexField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The index configuration to support vector search operations # @!attribute [rw] dimension # @return [::Integer] # Required. The vector dimension this configuration applies to. # # The resulting index will only include vectors of this dimension, and # can be used for vector search with the same dimension. # @!attribute [rw] flat # @return [::Google::Cloud::Firestore::Admin::V1::Index::IndexField::VectorConfig::FlatIndex] # Indicates the vector index is a flat index. class VectorConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An index that stores vectors in a flat data structure, and supports # exhaustive search. class FlatIndex include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # The supported orderings. module Order # The ordering is unspecified. Not a valid option. ORDER_UNSPECIFIED = 0 # The field is ordered by ascending field value. ASCENDING = 1 # The field is ordered by descending field value. DESCENDING = 2 end # The supported array value configurations. module ArrayConfig # The index does not support additional array queries. ARRAY_CONFIG_UNSPECIFIED = 0 # The index supports array containment queries. CONTAINS = 1 end end |