Class: Google::Cloud::Firestore::Admin::V1::Index::SearchIndexOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Firestore::Admin::V1::Index::SearchIndexOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/firestore/admin/v1/index.rb
Overview
Options for search indexes at the definition level.
Instance Attribute Summary collapse
-
#text_language ⇒ ::String
Optional.
-
#text_language_override_field_path ⇒ ::String
Optional.
Instance Attribute Details
#text_language ⇒ ::String
Returns Optional. The language to use for text search indexes. Used as the
default language if not overridden at the document level by specifying
the text_language_override_field. The language is specified as a BCP 47
language code.
For indexes with MONGODB_COMPATIBLE_API ApiScope: If unspecified, the
default language is English.
For indexes with ANY_API ApiScope: If unspecified, the default behavior
is autodetect.
255 256 257 258 |
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 255 class SearchIndexOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text_language_override_field_path ⇒ ::String
Returns Optional. The field in the document that specifies which language to use
for that specific document. For indexes with MONGODB_COMPATIBLE_API
ApiScope: if unspecified, the language is taken from the "language" field
if it exists or from text_language if it does not.
255 256 257 258 |
# File 'proto_docs/google/firestore/admin/v1/index.rb', line 255 class SearchIndexOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |